==> infinity-interface-client-0.1.7-20230605.103600-1-sources.jar: com/elitesland/cbpl/infinity/client/router/builder/impl/GeneralParamBuilder.java <==
package com.elitesland.cbpl.infinity.client.router.builder.impl;

import cn.hutool.core.util.ObjectUtil;
import com.elitesland.cbpl.infinity.client.router.builder.RouterParamBuilder;
import com.elitesland.cbpl.infinity.client.router.service.RouterAuthService;
import com.elitesland.cbpl.infinity.client.router.util.InfinityUtil;
import com.elitesland.cbpl.infinity.client.router.vo.RouterAuthVO;
import com.elitesland.cbpl.infinity.server.router.enums.AuthMethod;
import com.elitesland.cbpl.infinity.server.router.vo.param.InfinityRouterParamVO;
import com.elitesland.cbpl.infinity.web.common.vo.ResponseVO;
import com.elitesland.cbpl.infinity.web.http.param.HttpParam;
import com.elitesland.cbpl.unicom.annotation.UnicomTag;
import com.elitesland.unicom.context.Industry;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * @author eric.hao
 * @since 2021/07/13
 */
@Slf4j
@Service
@RequiredArgsConstructor
@UnicomTag(Industry.INDUSTRY_GENERAL)
public class GeneralParamBuilder implements RouterParamBuilder {

    private final RouterAuthService routerAuthService;

    @Override
    public <T, K extends ResponseVO> HttpParam<T, K> routerParamBuilder(
            InfinityRouterParamVO routerParam, Map<String, Object> requestBody, Class<T> resultType, Class<K> responseType) {
        // 接口相关配置项
        RouterAuthVO routerAuth = routerAuthService.queryRouterAuth(routerParam);
        HttpParam<T, K> params = new HttpParam<>();
        params.setUrl(routerAuth.getUrl());
        params.setRequestMethod(routerAuth.getRequestMethod());

        // 设置鉴权
        if (routerAuth.requiredAuth()) {
            // BASIC
            if (routerAuth.getAuthMethod().equals(AuthMethod.BASIC)) {
                params.setHeaders(InfinityUtil.setBasicAuth(routerAuth));
            }
//            // TODO 定制开发，可扩展：1.token的获取方式不确定；2.token的值要如何传不确定
//            else if (routerAuth.getAuthMethod().equals("TOKEN")) {
//                // requestBody.put("token", getToken());
//            }
            // 不进行鉴权
            else {
                log.trace("[INFINITY] NoAuth, RouterAuthVO({}).", routerAuth);
            }
        }

        // 设置request、response
        params.setBody(requestBody);
        if (ObjectUtil.isNotEmpty(resultType)) {
            params.setResultType(resultType);
        }
        if (ObjectUtil.isNotEmpty(responseType)) {
            params.setResponseType(responseType);
        }
        return params;
    }
}

==> infinity-interface-client-0.1.10-20230614.023348-1-sources.jar: com/elitesland/cbpl/infinity/client/router/builder/impl/GeneralParamBuilder.java <==
package com.elitesland.cbpl.infinity.client.router.builder.impl;

import cn.hutool.core.util.ObjectUtil;
import com.elitesland.cbpl.infinity.client.router.builder.RouterParamBuilder;
import com.elitesland.cbpl.infinity.client.router.service.RouterAuthService;
import com.elitesland.cbpl.infinity.client.router.util.InfinityUtil;
import com.elitesland.cbpl.infinity.client.router.vo.RouterAuthVO;
import com.elitesland.cbpl.infinity.server.router.enums.AuthMethod;
import com.elitesland.cbpl.infinity.server.router.vo.param.InfinityRouterParamVO;
import com.elitesland.cbpl.infinity.web.common.vo.ResponseVO;
import com.elitesland.cbpl.infinity.web.http.param.HttpParam;
import com.elitesland.cbpl.unicom.annotation.UnicomTag;
import com.elitesland.unicom.context.Industry;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * @author eric.hao
 * @since 2021/07/13
 */
@Slf4j
@Service
@RequiredArgsConstructor
@UnicomTag(Industry.INDUSTRY_GENERAL)
public class GeneralParamBuilder implements RouterParamBuilder<Object> {

    private final RouterAuthService routerAuthService;

    @Override
    public <T, K extends ResponseVO> HttpParam<T, K> routerParamBuilder(
            InfinityRouterParamVO routerParam, Object requestBody, Class<T> resultType, Class<K> responseType) {
        // 接口相关配置项
        RouterAuthVO routerAuth = routerAuthService.queryRouterAuth(routerParam);
        HttpParam<T, K> params = new HttpParam<>();
        params.setUrl(routerAuth.getUrl());
        params.setRequestMethod(routerAuth.getRequestMethod());

        // 设置鉴权
        if (routerAuth.requiredAuth()) {
            // BASIC
            if (routerAuth.getAuthMethod().equals(AuthMethod.BASIC)) {
                params.setHeaders(InfinityUtil.setBasicAuth(routerAuth));
            }
//            // TODO 定制开发，可扩展：1.token的获取方式不确定；2.token的值要如何传不确定
//            else if (routerAuth.getAuthMethod().equals("TOKEN")) {
//                // requestBody.put("token", getToken());
//            }
            // 不进行鉴权
            else {
                log.trace("[INFINITY] NoAuth, RouterAuthVO({}).", routerAuth);
            }
        }

        // 设置request、response
        params.setBody(requestBody);
        if (ObjectUtil.isNotEmpty(resultType)) {
            params.setResultType(resultType);
        }
        if (ObjectUtil.isNotEmpty(responseType)) {
            params.setResponseType(responseType);
        }
        return params;
    }
}
